@@ -113,6 +113,11 @@ class Serialize:
                     if field_value is not None:
                         instance_dict[field_set] = self.__serialize_list(field_value.all())
 
+                elif field.name in objects_cache:
+                    field_value = getattr(instance, field.name, None)
+                    if field_value is not None:
+                        instance_dict[field.name] = self.__serialize_list(field_value.all())
+
                 elif field.name not in fields_cache and getattr(instance, field_id, None) is not None:
                     instance_dict[field_id] = getattr(instance, field_id, None)
 
